@@ -1,13 +1,18 @@
-from pathlib import Path
 import midsv
+from pathlib import Path
 from collections import defaultdict
 
 
 def mask_control(TEMPDIR: Path, DICT_ALLELE: dict, CONTROL_NAME: str):
+    """
+    Mask loci that have less than 1% of matches in control seqence.
+    Alignments between control and knock-in alleles produses deletion loci in control.
+    The deletion loci are not sequencing error, so they should be ignored.
+    """
+    masks_control = defaultdict(list)
     for allele in DICT_ALLELE.keys():
         if allele == "control":
             continue
-        masks_control = defaultdict(list)
         path_midsv = Path(TEMPDIR, "midsv", f"{CONTROL_NAME}_{allele}.jsonl")
         cssplit_control = midsv.read_jsonl(path_midsv)
         cssplit_control = [cs["CSSPLIT"].split(",") for cs in cssplit_control]
